@@ -6,7 +6,7 @@
   \author  M. Gastineau 
            Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris. 
 
-   Copyright, 2008-2023, CNRS
+   Copyright, 2008-2024, CNRS
    email of the author : Mickael.Gastineau@obspm.fr
 */
 /*-----------------------------------------------------------------*/
@@ -113,6 +113,12 @@ double rint(double x);
 int vasprintf(char **ret, const char *format, va_list args);
 #endif
 
+#if defined(HAVE_SNPRINTF)
+#define calceph_snprintf snprintf
+#else
+int calceph_snprintf(char * str, size_t size, const char * format, ...);
+#endif
+
 /* platform without fseeko or ftello functions : android api <=24 */
 #ifndef HAVE_FSEEKO
 #define fseeko fseek
